@@ -1,5 +1,5 @@
 `design.rcbd` <-
-function (trt, r,serie=2,seed=0,kinds="Super-Duper",first=FALSE )
+function (trt, r,serie=2,seed=0,kinds="Super-Duper",first=TRUE,continue=FALSE )
 {
 number<-10
 if(serie>0) number<-10^serie
@@ -23,6 +23,11 @@ plots <- block*number+(1:ntr)
 book <- data.frame(plots, block = as.factor(block), trt = as.factor(mtr))
 names(book)[3] <- c(paste(deparse(substitute(trt))))
 names(book)[3]<-c(paste(deparse(substitute(trt))))
+if(continue){
+start0<-10^serie
+if(serie==0) start0<-0
+book$plots<-start0+1:nrow(book)
+}
 outdesign<-list(parameters=parameters,book=book)
 return(outdesign)
 }
